pub struct PrecomputedKey(pub [u8; 32]);Expand description
Applications that send several messages to the same receiver can gain speed by
splitting seal() into two steps, precompute() and seal_precomputed().
Similarly, applications that receive several messages from the same sender can gain
speed by splitting open() into two steps, precompute() and open_precomputed().
When a PrecomputedKey goes out of scope its contents will be zeroed out
Tuple Fields
0: [u8; 32]Implementations
Sourceimpl PrecomputedKey
impl PrecomputedKey
Sourcepub fn from_slice(bs: &[u8]) -> Option<PrecomputedKey>
pub fn from_slice(bs: &[u8]) -> Option<PrecomputedKey>
from_slice() creates an object from a byte slice
This function will fail and return None if the length of
the byte-slice isn’t equal to the length of the object